@@ -83,7 +83,7 @@ KgThemeSelector::KgThemeSelector(KgThemeProvider* provider, Options options, QWi
 		SLOT(_k_updateProviderSelection()));
 	//setup main layout
 	QVBoxLayout* layout = new QVBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	layout->addWidget(d->m_list);
 	//setup KNS button
 	if (options & EnableNewStuffDownload)
@@ -191,7 +191,7 @@ class KgThemeSelector::Dialog : public QDialog
 				buttonBox->addButton(stuff, QDialogButtonBox::ActionRole);
 				buttonBox->addButton(QDialogButtonBox::Close);
 
-			        connect(stuff, SIGNAL(clicked()), btn, SIGNAL(clicked()));
+			        connect(stuff, &QAbstractButton::clicked, btn, &QAbstractButton::clicked);
 				connect(buttonBox, &QDialogButtonBox::rejected, this, &KgThemeSelector::Dialog::reject);
 			}
 			else
